==> apache-brooklyn-0.11.0-src.zip: apache-brooklyn-0.11.0-src/brooklyn-server/core/src/main/java/org/apache/brooklyn/core/sensor/BasicAttributeSensor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.brooklyn.core.sensor;

import static com.google.common.base.Preconditions.checkNotNull;

import org.apache.brooklyn.api.sensor.AttributeSensor;
import org.apache.brooklyn.api.sensor.Sensor;

import com.google.common.reflect.TypeToken;

/**
 * A {@link Sensor} describing an attribute change.
 */
public class BasicAttributeSensor<T> extends BasicSensor<T> implements AttributeSensor<T> {
    private static final long serialVersionUID = -2493209215974820300L;
    
    private final SensorPersistenceMode persistence;

    public BasicAttributeSensor(Class<T> type, String name) {
        this(type, name, name);
    }
    
    public BasicAttributeSensor(Class<T> type, String name, String description) {
        this(TypeToken.of(type), name, description);
    }
    
    public BasicAttributeSensor(TypeToken<T> typeToken, String name) {
        this(typeToken, name, name);
    }
    
    public BasicAttributeSensor(TypeToken<T> typeToken, String name, String description) {
        this(typeToken, name, description, SensorPersistenceMode.REQUIRED);
    }
    
    public BasicAttributeSensor(TypeToken<T> typeToken, String name, String description, SensorPersistenceMode persistence) {
        super(typeToken, name, description);
        this.persistence = checkNotNull(persistence, "persistence");
    }

    @Override
    public SensorPersistenceMode getPersistenceMode() {
        // persistence could be null if deserializing state written by an old version; in which case default to 'required'
        return (persistence != null) ? persistence : SensorPersistenceMode.REQUIRED;
    }
}

==> apache-brooklyn-1.1.0-src.zip: apache-brooklyn-1.1.0-src/brooklyn-server/core/src/main/java/org/apache/brooklyn/core/sensor/BasicAttributeSensor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.brooklyn.core.sensor;

import static com.google.common.base.Preconditions.checkNotNull;

import org.apache.brooklyn.api.sensor.AttributeSensor;
import org.apache.brooklyn.api.sensor.Sensor;

import com.google.common.reflect.TypeToken;

/**
 * A {@link Sensor} describing an attribute change.
 */
public class BasicAttributeSensor<T> extends BasicSensor<T> implements AttributeSensor<T> {
    private static final long serialVersionUID = -2493209215974820300L;
    
    private final SensorPersistenceMode persistence;

    public BasicAttributeSensor(Class<T> type, String name) {
        this(type, name, name);
    }
    
    public BasicAttributeSensor(Class<T> type, String name, String description) {
        this(type, name, description, SensorPersistenceMode.REQUIRED);
    }
    
    public BasicAttributeSensor(TypeToken<T> typeToken, String name) {
        this(typeToken, name, name);
    }
    public BasicAttributeSensor(TypeToken<T> typeToken, String name, String description) {
        this(typeToken, name, description, SensorPersistenceMode.REQUIRED);
    }
    
    public BasicAttributeSensor(Class<T> type, String name, String description, SensorPersistenceMode persistence) {
        this(type, null, name, description, persistence);
    }
    public BasicAttributeSensor(TypeToken<T> typeToken, String name, String description, SensorPersistenceMode persistence) {
        this(null, typeToken, name, description, persistence);
    }
    public BasicAttributeSensor(Class<T> type, TypeToken<T> typeToken, String name, String description, SensorPersistenceMode persistence) {
        super(type, typeToken, name, description);
        this.persistence = checkNotNull(persistence, "persistence");
    }

    @Override
    public SensorPersistenceMode getPersistenceMode() {
        // persistence could be null if deserializing state written by an old version; in which case default to 'required'
        return (persistence != null) ? persistence : SensorPersistenceMode.REQUIRED;
    }
}
